# coding=utf-8
from __future__ import absolute_import, print_function

from suanpan.objects import Global

<<<<<<< HEAD
__version__ = "0.9.3"
=======
__version__ = "0.9.3"
>>>>>>> develop

g = Global()
